@@ -19,6 +19,8 @@ from concurrent.futures import ThreadPoolExecutor
 
 __all__ = [
     "install",
+    "fpcalc_bin",
+    "fpcalc_install",
     "exiv2_bin",
     "exiv2json_bin",
     "ipfs_bin",
